package edu.berkeley.sbp.util;
import java.util.*;

/** a mapping from keys of type <tt>K</tt> to <i>sets</i> of values of type <tt>T</tt> */
public final class HashMapBag<K,V> implements MapBag<K,V> {

    private final HashMap<K,HashSet<V>> hm = new HashMap<K,HashSet<V>>();

    public void add(K k, V v) {
        HashSet<V> hs = hm.get(k);
        if (hs==null) hm.put(k, hs = new HashSet<V>());
        hs.add(v);
    }

    public void addAll(K k, Iterable<V> iv) {
        for(V v : iv) add(k, v);
    }

    public HashSet<V> getAll(K k) {
        HashSet<V> ret = hm.get(k);
        if (ret==null) return new HashSet<V>();
        return ret;
    }

    public void remove(K k, V v) {
        if (hm.get(k)==null) return;
        hm.get(k).remove(v);
    }

    public void clear() { hm.clear(); }

    public boolean contains(K k, V v) {
        return hm.get(k)!=null && hm.get(k).contains(v);
    }

    public Iterator<K> iterator() { return hm.keySet().iterator(); }
}
